from ...config import config
from ...utils import text_response, User
from ...command_matcher import MC
import tsugu_api

import httpx


def handler(user: User, res: MC, platform: str, channel_id: str):
    data = tsugu_api.station_query_all_room()
    if not data.get('status'):
        return text_response('获取房间列表失败')
    return tsugu_api.room_list(data.get('data'))




import base64
from typing import List, Union, Dict

from .utils import *
from .utils import text_response
from . import remote
from . import local
from .utils import config
from loguru import logger
from tsugu_api import settings


def handler(message: str, user_id: str, platform: str, channel_id: str) -> List[Union[bytes, str]]:
    '''
    Tsugu Handler
    处理用户输入的自然语言，返回处理后的结果

    :param message: 用户消息
    :param user_id: 用户ID
    :param platform: 平台名称 一般为 red
    :param channel_id: 频道ID / 群号
    :return: List[Union[bytes, str]]
    '''
    data = handler_raw(message, user_id, platform, channel_id)
    response = []
    if not data:
        return response
    for item in data:
        response.append(item['string']) if item['type'] == 'string' else None
        response.append(base64.b64decode(item['string'].encode('utf-8')) if item['type'] == 'base64' else None)
    return response


def handler_raw(message: str, user_id: str, platform: str, channel_id: str) -> List[Dict[str, str]]:
    '''
    handler_raw 除了返回的数据类型不同外，其他与 handler 函数一致
    返回格式为 Tsugu 标准数据格式
    :param message: 用户消息
    :param user_id: 用户ID
    :param platform: 平台名称 一般为 red
    :param channel_id: 频道ID / 群号
    :return: List[Dict[str, str]]
    '''
    try:
        # 如果启用了本地数库
        if config._user_database_path:
            return r if (r := local.handler(message, user_id, platform, channel_id)) else None
        # 否则使用远程服务器
        return r if (r := remote.handler(message, user_id, platform, channel_id)) else None
    except Exception as e:
        logger.error(f'Error: {e}')
        raise e









import typing
from typing import List

from ..config import config

from tsugu_api._typing import _ServerId


class User:
    def __init__(self, user_id: str, platform: str, server_mode: _ServerId, default_server: List[_ServerId], car: bool, server_list: list):
        self.user_id: str = user_id
        self.platform: str = platform
        self.server_mode: _ServerId = server_mode
        self.default_server: List[_ServerId] = default_server
        self.car: bool = car
        self.server_list: list = server_list


class UserLocal(User):
    def __init__(self, user_id: str, platform: str, server_mode: _ServerId, default_server: List[_ServerId], car: bool, server_list: list, game_ids: list, verify_code: str):
        super().__init__(user_id, platform, server_mode, default_server, car, server_list)
        self.game_ids = game_ids
        self.verify_code = verify_code


def text_response(string):
    return [{"type": "string", "string": string}]


def server_names_2_server_ids(server_name: List[str]) -> List[_ServerId]:
    return [config._s_i[code] for code in server_name]


def server_name_2_server_id(server_name: str) -> _ServerId:
    return config._s_i[server_name] if server_name in config._s_i else None


def server_ids_2_server_names(index: List[_ServerId]) -> List[str]:
    return [config._i_s[code] for code in index]


def server_id_2_server_name(index: _ServerId) -> str:
    return config._i_s[index] if index in config._i_s else None


def server_exists(server):
    if server or server == 0:
        return True
    if not server:
        return False
    return False







from ...config import config
from ...utils import text_response, User
from ...command_matcher import MC
import tsugu_api
from ...utils import server_exists, server_name_2_server_id
from tsugu_api._typing import _ServerId, _Update


def handler(user: User, res: MC, platform: str, channel_id: str):
    # 获取用户数据
    if not res.args:
        # 查询默认服务器的玩家状态
        return tsugu_api.search_player(server=user.server_mode,
                                       player_id=user.server_list[user.server_mode]['playerId'])
    else:
        # 查询指定服务器的玩家状态
        server: _ServerId = server_name_2_server_id(res.args[0])
        # 服务器不存在
        if not server_exists(server):
            return text_response('未找到服务器，请输入正确的服务器名')
        player_id = user.server_list[server]['playerId']
        # 未绑定玩家
        if not player_id:
            return text_response('未绑定玩家，请先绑定玩家')
        # 查询玩家状态
        return tsugu_api.search_player(server=server, player_id=user.server_list[server]['playerId'])







from ...config import config
from ...utils import text_response, UserLocal
from ...command_matcher import MC
# import tsugu_api
from ...storage.db import db_manager
import json
import random


def generate_verify_code():
    # 不包含64和89的随机数
    while True:
        verify_code = random.randint(10000, 99999)
        if '64' not in str(verify_code) and '89' not in str(verify_code):
            return verify_code


def handler(user: UserLocal, res: MC, platform: str, channel_id: str):
    # 获取绑定请求
    cursor = db_manager.conn.cursor()
    verify_code = generate_verify_code()
    cursor.execute("UPDATE users SET verify_code = ? WHERE user_id = ? AND platform = ?", (verify_code, user.user_id, platform))
    db_manager.conn.commit()
    f'''正在绑定第{len(user.game_ids) + 1}个记录，请将 评论(个性签名) 或者 当前使用的 乐队编队名称改为\n{verify_code}\n稍等片刻等待同步后，发送\n验证 玩家ID 来完成本次身份验证\n例如：验证 10000xxxx 国服'''


from ...config import config
from ...utils import text_response, User, server_exists, server_name_2_server_id
from ...command_matcher import MC
import tsugu_api


def handler(user: User, res: MC, platform: str, channel_id: str):
    # 无参数
    if not res.args:
        return tsugu_api.ycx_all(user.server_mode)

    # 一个参数
    if len(res.args) == 1:
        # 两个参数都是数字
        if res.args[0].isdigit():
            if res.args[0].isdigit():
                event_id: int = int(res.args[0])
            else:
                return text_response('请输入正确的活动ID')
            return tsugu_api.ycx_all(user.server_mode, event_id)
        elif server_exists(server_pre := server_name_2_server_id(res.args[0])):
            user.server_mode = server_pre
            return tsugu_api.ycx_all(user.server_mode)
        else:
            return text_response('请输入正确的活动ID或服务器名称字母简写')

    if len(res.args) == 2:
        # 两个参数是 event_id server_mode
        if res.args[0].isdigit():
            event_id: int = int(res.args[0])
        else:
            return text_response('第一个参数请输入正确的活动ID')
        if server_exists(server_pre := server_name_2_server_id(res.args[1])):
            user.server_mode = server_pre
            return tsugu_api.ycx_all(user.server_mode, event_id)
        else:
            return text_response('第二个参数请输入正确的服务器名称字母简写')

    return text_response('参数过多(<=2)')



from ...config import config
from ...utils import text_response, User
from ...command_matcher import MC
import tsugu_api


def handler(user: User, res: MC, platform: str, channel_id: str):
    if not res.args:
        return text_response('请输入卡池ID(数字)')
    if not res.args[0].isdigit():
        return text_response('请输入正确的卡池ID(数字)')
    gacha_id: int = int(res.args[0])

    return tsugu_api.search_gacha(user.default_server, gacha_id)




from . import db
from . import remote_db


def _get_user(user_id: str, platform: str, local=False):
    if local:
        user = db.get_user(user_id, platform)
    else:
        user = remote_db.get_user(user_id, platform)
    return user


from ...config import config
from ...utils import text_response, User
from ...command_matcher import MC
import tsugu_api
from ...utils import server_exists, server_name_2_server_id


def handler(user: User, res: MC, platform: str, channel_id: str):
    if not res.args:
        return text_response('请输入正确的玩家ID和服务器名参数(可选)')
    if not res.args[0].isdigit():
        return text_response('请输入正确的玩家ID')
    player_id = int(res.args[0])
    if len(res.args) > 1:
        server_pre = server_name_2_server_id(res.args[1])
        if not server_exists(server_pre):
            return text_response('未找到服务器，请输入正确的服务器名')
        user.server_mode = server_pre

    r = tsugu_api.bind_player_verification(platform, user.user_id, user.server_mode, player_id, True)
    if r.get('status') != 'success':
        return text_response(r.get('data'))
    return text_response('绑定成功')

    # 车牌转发控制


